/* GrandPerspective, Version 3.5.1 
 *   A utility for Mac OS X that graphically shows disk usage. 
 * Copyright (C) 2005-2022, Erwin Bonsma 
 * 
 * This program is free software; you can redistribute it and/or modify it 
 * under the terms of the GNU General Public License as published by the Free 
 * Software Foundation; either version 2 of the License, or (at your option) 
 * any later version. 
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT 
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or 
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for 
 * more details. 
 * 
 * You should have received a copy of the GNU General Public License along 
 * with this program; if not, write to the Free Software Foundation, Inc., 
 * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA. 
 */

extern const NSUInteger TEXT_OUTPUT_BUFFER_SIZE;

@interface TextOutput : NSObject {
  FILE  *file;

  void  *dataBuffer;
  NSUInteger  dataBufferPos;
}

- (instancetype) init NS_UNAVAILABLE;
- (instancetype) initWithPath:(NSURL *)path NS_DESIGNATED_INITIALIZER;

@property (nonatomic, strong, readonly) NSURL *path;

- (BOOL) open;
- (BOOL) close;

- (BOOL) appendString:(NSString *)s;
- (BOOL) flush;

@end
